@@ -80,4 +80,20 @@ class TestCommandsOnStrings < Test::Unit::TestCase
     assert_equal "s2", r.get("foo")
     assert_equal "s3", r.get("bar")
   end
+
+  def test_bitop
+    return if version < "2.5.10"
+
+    r.set("foo", "a")
+    r.set("bar", "b")
+
+    r.bitop(:and, "foo&bar", "foo", "bar")
+    assert_equal "\x60", r.get("foo&bar")
+    r.bitop(:or, "foo|bar", "foo", "bar")
+    assert_equal "\x63", r.get("foo|bar")
+    r.bitop(:xor, "foo^bar", "foo", "bar")
+    assert_equal "\x03", r.get("foo^bar")
+    r.bitop(:not, "~foo", "foo")
+    assert_equal "\x9E", r.get("~foo")
+  end
 end
