@@ -45,4 +45,15 @@ class TestDistributedCommandsOnStrings < Test::Unit::TestCase
       r.mapped_msetnx(:foo => "s2", :bar => "s3")
     end
   end
+
+  def test_bitop
+    return if version < "2.5.10"
+
+    assert_raise Redis::Distributed::CannotDistribute do
+      r.set("foo", "a")
+      r.set("bar", "b")
+
+      r.bitop(:and, "foo&bar", "foo", "bar")
+    end
+  end
 end
