@@ -145,4 +145,20 @@ class TestDistributedCommandsRequiringClustering < Test::Unit::TestCase
     r.sort("{qux}bar", :get => "{qux}foo:*", :store => "{qux}baz")
     assert_equal ["s1", "s2"], r.lrange("{qux}baz", 0, -1)
   end
+
+  def test_bitop
+    return if version < "2.5.10"
+
+    r.set("{qux}foo", "a")
+    r.set("{qux}bar", "b")
+
+    r.bitop(:and, "{qux}foo&bar", "{qux}foo", "{qux}bar")
+    assert_equal "\x60", r.get("{qux}foo&bar")
+    r.bitop(:or, "{qux}foo|bar", "{qux}foo", "{qux}bar")
+    assert_equal "\x63", r.get("{qux}foo|bar")
+    r.bitop(:xor, "{qux}foo^bar", "{qux}foo", "{qux}bar")
+    assert_equal "\x03", r.get("{qux}foo^bar")
+    r.bitop(:not, "{qux}~foo", "{qux}foo")
+    assert_equal "\x9E", r.get("{qux}~foo")
+  end
 end
