@@ -67,8 +67,6 @@ class TestPublishSubscribe < Test::Unit::TestCase
           @unsubscribed = true
           @t2 = total
         end
-
-        listening = true
       end
     end
 
@@ -134,7 +132,7 @@ class TestPublishSubscribe < Test::Unit::TestCase
   def test_subscribe_past_a_timeout
     # For some reason, a thread here doesn't reproduce the issue.
     sleep = %{sleep #{OPTIONS[:timeout] * 2}}
-    publish = %{echo "publish foo bar\r\n" | nc localhost #{OPTIONS[:port]}}
+    publish = %{echo "publish foo bar\r\n" | nc -N localhost #{OPTIONS[:port]}}
     cmd = [sleep, publish].join("; ")
 
     IO.popen(cmd, "r+") do |pipe|
